==> walkers-fabric-1.20.1-5.3.1-sources.jar: tocraft/walkers/impl/variant/TropicalFishTypeProvider.java <==
package tocraft.walkers.impl.variant;

import net.minecraft.class_1299;
import net.minecraft.class_1474;
import net.minecraft.class_1937;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_5250;
import tocraft.walkers.Walkers;
import tocraft.walkers.api.variant.TypeProvider;

public class TropicalFishTypeProvider extends TypeProvider<class_1474> {

    @Override
    public int getVariantData(class_1474 entity) {
        //#if MC>1182
        class_1474.class_7992 variant = new class_1474.class_7992(entity.method_47862(), entity.method_6658(), entity.method_6655());
        for (class_1474.class_7992 commonVariant : class_1474.field_41573) {
            if (commonVariant.method_47872() == variant.method_47872()) {
                return class_1474.field_41573.indexOf(commonVariant);
            }
        }
        //#else
        //$$ if (TropicalFish.COMMON_VARIANTS.length > 0) {
        //$$     for (int i = 0; i < TropicalFish.COMMON_VARIANTS.length; i++) {
        //$$         if (TropicalFish.COMMON_VARIANTS[i] == entity.getVariant()) {
        //$$             return i;
        //$$         }
        //$$     }
        //$$ }
        //#endif
        return getFallbackData();
    }

    @Override
    public class_1474 create(class_1299<class_1474> type, class_1937 world, int data) {
        class_2487 tag = new class_2487();
        //#if MC>1182
        tag.method_10569("Variant", class_1474.field_41573.get(data).method_47872());
        //#else
        //$$ tag.putInt("Variant", TropicalFish.COMMON_VARIANTS[data]);
        //#endif

        class_2487 compoundTag = tag.method_10553();
        compoundTag.method_10582("id", class_1299.method_5890(type).toString());
        return (class_1474) class_1299.method_17842(compoundTag, world, entity -> entity);
    }

    @Override
    public int getFallbackData() {
        return 0;
    }

    @Override
    public int getRange() {
        //#if MC>1182
        return class_1474.field_41573.size() - 1;
        //#else
        //$$ return TropicalFish.COMMON_VARIANTS.length - 1;
        //#endif
    }

    @Override
    public class_2561 modifyText(class_1474 entity, class_5250 text) {
        //#if MC>1182
        return entity.method_47862().method_47871();
        //#else
        //$$ return text;
        //#endif
    }
}

==> walkers-fabric-1.20.2-4.4.1-sources.jar: tocraft/walkers/impl/variant/TropicalFishTypeProvider.java <==
package tocraft.walkers.impl.variant;

import net.minecraft.class_1299;
import net.minecraft.class_1474;
import net.minecraft.class_1937;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_5250;
import net.minecraft.class_7923;
import tocraft.walkers.api.variant.TypeProvider;

public class TropicalFishTypeProvider extends TypeProvider<class_1474> {

    @Override
    public int getVariantData(class_1474 entity) {
        class_1474.class_7992 variant = new class_1474.class_7992(entity.method_47862(), entity.method_6658(), entity.method_6655());
        for (class_1474.class_7992 commonVariant : class_1474.field_41573) {
            if (commonVariant.method_47872() == variant.method_47872()) {
                return class_1474.field_41573.indexOf(commonVariant);
            }
        }
        return getFallbackData();
    }

    @Override
    public class_1474 create(class_1299<class_1474> type, class_1937 world, int data) {
        class_2487 tag = new class_2487();

        tag.method_10569("Variant", class_1474.field_41573.get(data).method_47872());

        class_2487 compoundTag = tag.method_10553();
        compoundTag.method_10582("id", class_7923.field_41177.method_10221(type).toString());
        return (class_1474) class_1299.method_17842(compoundTag, world, entity -> entity);
    }

    @Override
    public int getFallbackData() {
        return 0;
    }

    @Override
    public int getRange() {
        return class_1474.field_41573.size() - 1;
    }

    @Override
    public class_2561 modifyText(class_1474 entity, class_5250 text) {
        return entity.method_47862().method_47871();
    }
}
